//
//      bolometr.cpp - Compute
//      		1) The bolometric correction B.C. for a star
//                         from the measured visual magnitudes m1,m2 at
//			   two zenith angles alpha1 and alpha2.
//                     2) The observed visual magnitude m0 to be expected
//                        at the earths surface for a star at the zenith
//			  given the measured visual magnitudes at the
//			  two zenith angles alpha1 and alpha2.
//   			  This is the star chart magnitude that is
//			  input to STARCAL or STAREXP.
//                     3) The bolometric visual magnitude m_bol
//                        for the star as observed above the atmosphere.
// 
//         The measurement theory is taken from pages 385-386
//	   of THERMONUCLEAR FUSION IN STARS by James A. Green,
//         from the Supplemental Notes for the 1st edition.
//
//                      - Author: James A. Green.
//			- Compiler: Borland C/C++
//
//
#include <stdio.h>
#include <math.h>
#include <string.h>
#include <stdlib.h>
main()
{
	char value[20];   // variable input string.
	double d;         // the floating point value of the above string.
	double m1;        // the visual magnitude m1.
	double m2;        // the visual magnitude m2.
	double alpha1;      // the zenith angle alpha1 for m1 in degrees.	
	double alpha2;   // the zenith angle alpha2 for m2 in degrees.
	double alpha1rad;  // the zenith angle alpha1 in radians.
	double alpha2rad;  // the zenith angle alpha2 in radians.
	double sec(double a); // 1.0/cos(a).
	double sec1;    // secant(alpha1).
	double sec2;    // secant(alpha2).
	double bc;      // bolometric correction B.C.
	double m0;	// visual magnitude expected to be observed at zenith angle 0.
	double mbol;    // visual magnitude expected above the atmosphere at zenith angle 0.

	int more = 1;

     while(more == 1){
	printf("bolometr.cpp - Computes:\n");
	printf("  1) The bolometric correction B.C. from observations of\n");
	printf("     the visual magnitudes m1, m2 made at the zenith \n");
	printf("     angles alpha1, alpha2 degrees.\n");
	printf("  2) The visual magnitude m0 expectation value for the\n");
	printf("     star when at the zenith, when alpha is zero.\n");
	printf("     This is the visual magnitude input to STARCAL.\n");
	printf("  3) The corrected magnitude m_bol expected when the\n");
	printf("     visual magnitude is measured above the atmosphere.\n\n");  
	printf("Enter alpha1, the zenith angle for m1 in floating-point: ");
	scanf("%s",value);   // This
        d = atof(value);     // entry procedure is more immune to invalid inputs
	alpha1 = d;          // than simple scanf().

	printf("Enter alpha2, the zenith angle for m2 in floating-point: ");
	scanf("%s",value);   // This
        d = atof(value);     // entry procedure is more immune to invalid inputs
	alpha2 = d;          // than simple scanf().

	printf("Enter m1, the visual magnitude at alpha1 in floating-point: ");
	scanf("%s",value);   // This
        d = atof(value);     // entry procedure is more immune to invalid inputs
	m1 = d;          // than simple scanf().

	printf("Enter m2, the visual magnitude at alpha2 in floating-point: ");
	scanf("%s",value);   // This
	d = atof(value);     // entry procedure is more immune to invalid inputs
	m2 = d;              // than simple scanf().
//
//    Compute results.
//
	printf("\n");
	alpha1rad = (3.14159/180.0)*alpha1;  // convert to radian measure
	alpha2rad = (3.14159/180.0)*alpha2;
	printf("m1 = %f, alpha1 = %f degrees, alpha1 = %f radians\n", m1, alpha1, alpha1rad);
	printf("m2 = %f, alpha2 = %f degrees, alpha1 = %f radians\n", m2, alpha2, alpha2rad);
	

	sec1 = sec(alpha1rad);
	sec2 = sec(alpha2rad);

	printf("\ncos(alpha1) = %f, sec(alpha1)= %f .\n", cos(alpha1rad), sec(alpha1rad));
	printf("cos(alpha2) = %f, sec(alpha2)= %f .\n", cos(alpha2rad), sec(alpha2rad));

	bc = (m2 - m1)/(sec1 - sec2);
	m0 = m1 + bc*(sec1 - 1.0);
	mbol = m0 + bc;

	printf("\n");
	printf("B.C. = %f, m0 = %f, m_bol = %f.\n", bc, m0, mbol);
	printf("REF: Sup.Notes,1st edition,THERMONUC.FUSION IN STARS,pp.385-386.\n");

//
//    Ask for repeat or discontinue decision.
//
	printf("\nEnter 1 to continue or 0 to exit:");
	scanf("%d", &more);
	printf("\n");
	if(more == 0) exit;
     }
}
//
// secant(a) = 1/cos(a)
//
double sec(double a)
{
	double secant;

	secant = 1.0/cos(a);

	
        return(secant);
}




































































































































































































































































































































































































































































































